==> puppet-module-octavia_20.3.0.orig.tar.xz: puppet-module-octavia-20.3.0/spec/classes/octavia_db_postgresql_spec.rb <==
require 'spec_helper'

describe 'octavia::db::postgresql' do

  shared_examples_for 'octavia::db::postgresql' do
    let :req_params do
      { :password => 'octaviapass' }
    end

    let :pre_condition do
      'include postgresql::server'
    end

    context 'with only required parameters' do
      let :params do
        req_params
      end

      it { is_expected.to contain_class('octavia::deps') }

      it { is_expected.to contain_openstacklib__db__postgresql('octavia').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
      it { is_expected.to_not contain_openstacklib__db__postgresql('octavia_persistence') }
    end

    context 'with persistence database enabled' do
      let :params do
        req_params.merge!(:persistence_dbname => 'octavia_persistence')
      end

      it { is_expected.to contain_class('octavia::deps') }

      it { is_expected.to contain_openstacklib__db__postgresql('octavia').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
      it { is_expected.to contain_openstacklib__db__postgresql('octavia_persistence').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia_persistence',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
    end
  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          :processorcount => 8,
          :concat_basedir => '/var/lib/puppet/concat'
        }))
      end

      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
        it_configures 'octavia::db::postgresql'
      end
    end
  end

end

==> puppet-module-octavia_21.0.0.orig.tar.xz: puppet-module-octavia-21.0.0/spec/classes/octavia_db_postgresql_spec.rb <==
require 'spec_helper'

describe 'octavia::db::postgresql' do

  shared_examples_for 'octavia::db::postgresql' do
    let :req_params do
      { :password => 'octaviapass' }
    end

    let :pre_condition do
      'include postgresql::server'
    end

    context 'with only required parameters' do
      let :params do
        req_params
      end

      it { is_expected.to contain_class('octavia::deps') }

      it { is_expected.to contain_openstacklib__db__postgresql('octavia').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
      it { is_expected.to_not contain_openstacklib__db__postgresql('octavia_persistence') }
    end

    context 'with persistence database enabled' do
      let :params do
        req_params.merge!(:persistence_dbname => 'octavia_persistence')
      end

      it { is_expected.to contain_class('octavia::deps') }

      it { is_expected.to contain_openstacklib__db__postgresql('octavia').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
      it { is_expected.to contain_openstacklib__db__postgresql('octavia_persistence').with(
        :user       => 'octavia',
        :password   => 'octaviapass',
        :dbname     => 'octavia_persistence',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
    end
  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          # puppet-postgresql requires the service_provider fact provided by
          # puppetlabs-postgresql.
          :service_provider => 'systemd'
        }))
      end

      it_configures 'octavia::db::postgresql'
    end
  end

end
